@@ -3,7 +3,6 @@ import typer
 from ..consoles import (
     console,
 )
-from .deploy import app as deploy_app
 from .init import app as init_app
 from .new import app as new_app
 from .set import app as set_app
@@ -12,7 +11,6 @@ from .utils import app as utils_app
 app = typer.Typer(add_completion=False)
 app.add_typer(init_app, name="init")
 app.add_typer(new_app, name="new")
-app.add_typer(deploy_app, name="deploy")
 app.add_typer(utils_app, name="utils")
 app.add_typer(set_app, name="set")
 
